@@ -1,3 +1,4 @@
+import shutil
 from pathlib import Path
 from tomllib import load
 from ls_buildtools.protect import Protector
@@ -15,6 +16,6 @@ try:
 					print(f"- Protecting file: {A}");C,D=E.protect_file(A,A)
 					if D is not None:
 						if C.absolute()!=A.absolute():A.unlink()
-						if D.absolute()!=C.absolute():C.rename(D.absolute())
+						if D.absolute()!=C.absolute():shutil.move(C.absolute(),D.absolute())
 					else:A.unlink();C.unlink(missing_ok=True)
 except ImportError:pass
\ No newline at end of file
